export class Main extends Indicator {

    constructor() {
        super();
        
        this.addInput("period", InputType.int, 10);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            upper : this.addBuffer(),
            middle : this.addBuffer(),
            lower : this.addBuffer(),
        };
    }

    onInit() {
        this.buffers.upper
            .setShape(Shape.Line)
            .setColor(Color.White)
            .setDrawBegin(0)
        ;

        this.buffers.middle
            .setShape(Shape.Line)
            .setColor(Color.White)
            .setDrawBegin(0)
        ;

        this.buffers.lower
            .setShape(Shape.Line)
            .setColor(Color.White)
            .setDrawBegin(0)
        ;
    }



    async onUpdate() {
        const {period, PriceType} = this.getInputs(),
            {upper, middle, lower} = this.buffers,
            {
                High,
                Low,
                Close,
            } = await Bar.load([
                Bar.Mode.High,
                Bar.Mode.Low,
                Bar.Mode.Close,
            ], PriceType),
            barSize = Close.length;

        let limit, x, list, avg,
            nCountedBars = Bar.counted();

        if (nCountedBars < 0) return (-1);
        if (nCountedBars > 0) nCountedBars--;
        limit = barSize - nCountedBars;

        list = await Indicators.MA(null, 0, period, 0, Averaging.Simple, AppliedPrice.Typical, PriceType);

        for (x = 0; x < limit; x++) {
            middle.set(x, list[x]);
            avg = this.findAvg(period, x, High, Low);
            upper.set(x, (middle.get(x) + avg));
            lower.set(x, (middle.get(x) - avg));
        }
    }

    findAvg(period, shift, high, low) {
        let sum = 0, x;
        for (x = shift; x < (shift + period); x++) {
            sum += high[x] - low[x];
        }
        sum = sum / period;
        return (sum);
    }
}